

.. This file contains all links we use for documentation in a centralized place


.. _idiap: http://www.idiap.ch
.. _bob: http://www.idiap.ch/software/bob
.. _buildout: http://www.buildout.org
.. _pypi: http://pypi.python.org
.. _installation: https://www.idiap.ch/software/bob/install
.. _replay-attack: https://www.idiap.ch/dataset/replayattack
.. _replay-mobile: https://www.idiap.ch/dataset/replay-mobile
.. _dependencies: https://gitlab.idiap.ch/bob/bob/wikis/Dependencies
.. _MIFS: http://www.antitza.com/makeup-datasets.html
.. _CELEBA: http://mmlab.ie.cuhk.edu.hk/projects/CelebA.html
.. _Swan: https://www.idiap.ch/dataset/swan
.. _oulu-npu: https://sites.google.com/site/oulunpudatabase/
.. _casia-fasd: http://www.cbsr.ia.ac.cn/english/FaceAntiSpoofDatabases.asp
.. _casia-surf: https://sites.google.com/qq.com/face-anti-spoofing/welcome/challengecvpr2019
.. _mask-attack: https://www.idiap.ch/en/dataset/3dmad/index_html
